@@ -1,5 +1,5 @@
 # python-android
-# Copyright (C) 2010 Chris Soyars
+# Copyright (C) 2010-2012 Chris Soyars
 #
 # This progream is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,10 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-class AndroidException():
-    pass
-
-class NoFilenameException(AndroidException):
+class AndroidException(Exception):
     pass
 
 class FileNotFoundException(AndroidException):
